@@ -4,8 +4,7 @@ from autocoder.auto_coder_runner import (
     load_memory,
     save_memory,
     configure,
-    manage_models,
-    print_conf,
+    manage_models,    
     exclude_dirs,
     exclude_files,
     ask,
@@ -33,19 +32,30 @@ from autocoder.auto_coder_runner import (
     completer,
     summon,
     get_memory,
+    get_all_extensions
 )
 
 class AutoCoderRunnerWrapper:
     def __init__(self, project_path: str, product_mode: str = "lite"):
+        self.project_path = project_path
+        self.product_mode = product_mode
         load_memory()
         load_tokenizer()
-
+    
+    def get_all_extensions_wrapper(self):
+        return get_all_extensions(self.project_path)
 
     def auto_command_wrapper(self, command: str, params: Dict[str, Any]) -> Dict[str, str]:
         return auto_command(command,params)
     
     def configure_wrapper(self,conf: str, skip_print=False ):
-        return configure(conf, skip_print)    
+        return configure(conf, skip_print)  
+
+    def build_index_wrapper(self):
+        return index_build()  
+    
+    def query_index_wrapper(self,query: str):
+        return index_query(query)
 
     def get_conf_wrapper(self):
         memory = get_memory()
