@@ -50,7 +50,7 @@ def get_repo(project_path: str) -> Repo:
 
 @router.get("/api/commits")
 async def get_commits(
-    limit: int = 50, 
+    limit: int = 10, 
     skip: int = 0, 
     project_path: str = Depends(get_project_path)
 ):
@@ -328,7 +328,8 @@ async def get_file_diff(
                 return {
                     "before_content": "",  # 初始提交前没有内容
                     "after_content": file_content,
-                    "diff_content": repo.git.show(f"{commit.hexsha} -- {file_path}")
+                    "diff_content": repo.git.show(f"{commit.hexsha} -- {file_path}"),
+                    "file_status": "added"
                 }
             else:
                 raise HTTPException(status_code=404, detail=f"File {file_path} not found in commit {commit_hash}")
@@ -336,51 +337,61 @@ async def get_file_diff(
         # 获取父提交
         parent = commit.parents[0]
         
-        # 检查文件是否存在于当前提交
-        file_in_commit = False
-        try:
-            after_content = repo.git.show(f"{commit.hexsha}:{file_path}")
-            file_in_commit = True
-        except git.GitCommandError:
-            after_content = ""  # 文件在当前提交中不存在（可能被删除）
+        # 获取提交的差异索引
+        diff_index = parent.diff(commit)
         
-        # 检查文件是否存在于父提交
-        file_in_parent = False
-        try:
-            before_content = repo.git.show(f"{parent.hexsha}:{file_path}")
-            file_in_parent = True
-        except git.GitCommandError:
-            before_content = ""  # 文件在父提交中不存在（新增文件）
+        # 初始化变量
+        before_content = ""
+        after_content = ""
+        diff_content = ""
+        file_status = "unknown"
+        found_file = False
         
-        # 获取文件差异
-        try:
-            diff_content = repo.git.diff(f"{parent.hexsha}..{commit.hexsha}", "--", file_path)
-        except git.GitCommandError:
-            # 如果无法直接获取差异，可能是重命名或其他特殊情况
-            diff_content = ""
-            
-            # 尝试查找可能的重命名
-            diff_index = parent.diff(commit)
-            for diff_item in diff_index:
-                if diff_item.renamed:
-                    if diff_item.b_path == file_path:  # 重命名后的路径匹配
+        # 查找匹配的文件差异
+        for diff_item in diff_index:
+            # 检查文件路径是否匹配当前或重命名后的文件
+            if diff_item.a_path == file_path or diff_item.b_path == file_path:
+                found_file = True
+                # 根据diff_item确定文件状态
+                file_status = get_file_status_from_diff(diff_item)
+                
+                # 根据文件状态获取内容
+                if file_status == "added":
+                    # 新增文件
+                    after_content = repo.git.show(f"{commit.hexsha}:{file_path}")
+                    diff_content = repo.git.diff(f"{parent.hexsha}..{commit.hexsha}", "--", file_path)
+                elif file_status == "deleted":
+                    # 删除文件
+                    before_content = repo.git.show(f"{parent.hexsha}:{file_path}")
+                    diff_content = repo.git.diff(f"{parent.hexsha}..{commit.hexsha}", "--", file_path)
+                elif file_status == "renamed":
+                    # 重命名文件
+                    if diff_item.a_path == file_path:
+                        # 查询的是原文件名
                         before_content = repo.git.show(f"{parent.hexsha}:{diff_item.a_path}")
-                        diff_content = repo.git.diff(f"{parent.hexsha}..{commit.hexsha}", "--", diff_item.a_path, file_path)
-                        break
-                    elif diff_item.a_path == file_path:  # 重命名前的路径匹配
                         after_content = repo.git.show(f"{commit.hexsha}:{diff_item.b_path}")
-                        diff_content = repo.git.diff(f"{parent.hexsha}..{commit.hexsha}", "--", file_path, diff_item.b_path)
-                        break
+                    else:
+                        # 查询的是新文件名
+                        before_content = repo.git.show(f"{parent.hexsha}:{diff_item.a_path}")
+                        after_content = repo.git.show(f"{commit.hexsha}:{diff_item.b_path}")
+                    diff_content = repo.git.diff(f"{parent.hexsha}..{commit.hexsha}", "--", diff_item.a_path, diff_item.b_path)
+                else:
+                    # 修改文件
+                    before_content = repo.git.show(f"{parent.hexsha}:{file_path}")
+                    after_content = repo.git.show(f"{commit.hexsha}:{file_path}")
+                    diff_content = repo.git.diff(f"{parent.hexsha}..{commit.hexsha}", "--", file_path)
+                
+                break
         
-        # 检查我们是否找到了内容
-        if not file_in_commit and not file_in_parent:
+        # 如果没有找到匹配的文件
+        if not found_file:
             raise HTTPException(status_code=404, detail=f"File {file_path} not found in commit {commit_hash} or its parent")
         
         return {
             "before_content": before_content,
             "after_content": after_content,
             "diff_content": diff_content,
-            "file_status": "added" if not file_in_parent else "deleted" if not file_in_commit else "modified"
+            "file_status": file_status
         }
         
     except HTTPException:
@@ -393,6 +404,28 @@ async def get_file_diff(
         )
 
 
+def get_file_status_from_diff(diff_item) -> str:
+    """
+    根据Git diff对象确定文件变更类型
+    
+    Args:
+        diff_item: Git diff对象
+        
+    Returns:
+        文件状态: added(新增), deleted(删除), renamed(重命名), copied(复制) 或 modified(修改)
+    """
+    if diff_item.new_file:
+        return "added"
+    elif diff_item.deleted_file:
+        return "deleted"
+    elif diff_item.renamed:
+        return "renamed"
+    elif diff_item.copied:
+        return "copied"
+    else:
+        return "modified"
+
+
 @router.get("/api/current-changes")
 async def get_current_changes(
     limit: int = 3, 
@@ -426,20 +459,16 @@ async def get_current_changes(
             logger.info(f"使用事件文件模式获取提交, event_file_id={event_file_id}")
             try:
                 # 获取事件文件路径
-                event_file_path = get_event_file_path(event_file_id, project_path)
-                logger.info(f"事件文件路径: {event_file_path}")
+                event_file_path = get_event_file_path(event_file_id, project_path)                
                 
                 # 获取事件管理器
-                event_manager = get_event_manager(event_file_path)
-                logger.info(f"成功获取事件管理器")
+                event_manager = get_event_manager(event_file_path)                
                 
                 # 获取所有事件
-                all_events = event_manager.event_store.get_events()
-                logger.info(f"获取事件总数: {len(all_events)}")
+                all_events = event_manager.event_store.get_events()                
                 
                 # 创建ActionYmlFileManager实例
-                action_manager = ActionYmlFileManager(project_path)                                                
-                logger.info(f"成功创建ActionYmlFileManager实例")
+                action_manager = ActionYmlFileManager(project_path)                                                                
 
                 action_files = set()
                 final_action_files = []
@@ -447,37 +476,28 @@ async def get_current_changes(
                 # 记录事件中包含action_file字段的事件数量
                 action_file_count = 0
                 
-                for i, event in enumerate(all_events):
-                    logger.debug(f"处理事件 {i+1}/{len(all_events)}, 事件类型: {event.event_type}")
+                for i, event in enumerate(all_events):                    
                     # 检查元数据中是否有action_file字段
                     if 'action_file' in event.metadata and event.metadata['action_file']:
                         action_file_count += 1
-                        action_file = event.metadata['action_file']
-                        logger.debug(f"事件 {i+1} 包含action_file: {action_file}")
+                        action_file = event.metadata['action_file']                        
                         
-                        if action_file in action_files:
-                            logger.debug(f"跳过重复的action_file: {action_file}")
+                        if action_file in action_files:                            
                             continue
                                                 
                         action_files.add(action_file)
                         # 从action文件获取提交ID       
                         # action_file 这里的值是 类似这样的 actions/000000000104_chat_action.yml
                         if action_file.startswith("actions"):
-                            action_file = action_file[len("actions/"):]
-                            logger.debug(f"处理后的action_file: {action_file}")
+                            action_file = action_file[len("actions/"):]                            
 
                         final_action_files.append(action_file)
-                
-                logger.info(f"从 {len(all_events)} 个事件中提取到 {action_file_count} 个包含action_file的事件")
-                logger.info(f"去重后得到 {len(action_files)} 个唯一action_file")
-                logger.info(f"最终处理的action_files: {final_action_files}")
+                                
                 
                 commits = []
-                for i, action_file in enumerate(final_action_files):
-                    logger.info(f"处理action文件 {i+1}/{len(final_action_files)}: {action_file}")
+                for i, action_file in enumerate(final_action_files):                    
                     commit_ids = action_manager.get_all_commit_id_from_file(action_file)                                        
-                    
-                    logger.info(f"从action文件 {action_file} 获取到的提交ID列表: {commit_ids}")
+                                        
                     
                     if not commit_ids:
                         logger.warning(f"无法从action文件 {action_file} 获取提交ID")
@@ -492,8 +512,7 @@ async def get_current_changes(
                         for cid in commit_ids:
                             try:
                                 commit = repo.commit(cid)
-                                message = commit.message.strip()
-                                logger.info(f"检查提交 {cid[:7]} 是否为revert提交，消息: {message[:50]}...")
+                                message = commit.message.strip()                                
                                 
                                 if message.startswith("<revert>"):
                                     logger.info(f"找到revert提交: {cid}")
@@ -503,20 +522,16 @@ async def get_current_changes(
                                 logger.warning(f"检查提交 {cid} 时出错: {str(e)}")
                         
                         # 如果找到revert提交，只处理这个提交
-                        if revert_commit_id:
-                            logger.info(f"将只处理revert提交: {revert_commit_id}")
+                        if revert_commit_id:                            
                             commit_ids = [revert_commit_id]
                     
                     # 处理所有提交ID（或者只处理revert提交）
                     for commit_id in commit_ids:
                         # 验证提交ID是否存在于仓库中
-                        try:
-                            logger.info(f"获取提交详情: {commit_id}")
+                        try:                            
                             commit = repo.commit(commit_id)
                             # 获取提交统计信息
-                            stats = commit.stats.total
-                            logger.info(f"提交统计信息: 插入={stats['insertions']}, 删除={stats['deletions']}, 文件变更={stats['files']}")
-                            
+                            stats = commit.stats.total                            
                             # 构建提交信息
                             commit_info = {
                                 "hash": commit.hexsha,
@@ -532,18 +547,14 @@ async def get_current_changes(
                                 }
                             }
                             commits.append(commit_info)
-                            logger.info(f"成功添加提交信息到结果列表，当前结果数: {len(commits)}")
                         except Exception as e:
                             logger.warning(f"无法获取提交 {commit_id} 的详情: {str(e)}")
                 
-                logger.info(f"处理完所有action文件，共找到 {len(commits)} 个提交")
                 
                 # 按提交时间戳排序（降序 - 最新的在前面）
                 if commits:
                     commits.sort(key=lambda x: x['timestamp'], reverse=True)
-                    logger.info("提交已按时间戳降序排序")
-                                
-                logger.info(f"返回结果: {len(commits)} 个提交")
+                                                
                 return {"commits": commits, "total": len(commits)}
             
             except Exception as e:
